==> jc-1.4.0.tar.gz: gnu/xml/transform/Key.h <==
// class gnu.xml.transform.Key

// class file dependencies
// @dep_class a8e21f5a8a9bccaa gnu_xml_transform_Key
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_transform_Key_H_
#define _JC_gnu_xml_transform_Key_H_

// Forward structure declarations
struct _jc_gnu_xml_transform_Key$object;
struct _jc_gnu_xml_transform_Stylesheet$object;
struct _jc_gnu_xml_xpath_Expr$object;
struct _jc_gnu_xml_xpath_Pattern$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_xml_namespace_QName$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_Key$sub_refs	_jc_gnu_xml_transform_Key$sub_refs;
typedef struct _jc_gnu_xml_transform_Key$sub_nonrefs	_jc_gnu_xml_transform_Key$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_Key$refs	_jc_gnu_xml_transform_Key$refs;
typedef struct _jc_gnu_xml_transform_Key$nonrefs	_jc_gnu_xml_transform_Key$nonrefs;
typedef struct _jc_gnu_xml_transform_Key$object	_jc_gnu_xml_transform_Key$object;

typedef const struct _jc_gnu_xml_transform_Key$vmethods	_jc_gnu_xml_transform_Key$vmethods;
typedef const struct _jc_gnu_xml_transform_Key$vtable	_jc_gnu_xml_transform_Key$vtable;
typedef const struct _jc_gnu_xml_transform_Key$vtype	_jc_gnu_xml_transform_Key$vtype;

// Constructors
extern void _jc_gnu_xml_transform_Key$method$_init$08cf062a5167e0de(_jc_env *, struct _jc_gnu_xml_transform_Key$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_gnu_xml_xpath_Pattern$object *, struct _jc_gnu_xml_xpath_Expr$object *);

// Virtual methods
extern struct _jc_gnu_xml_transform_Key$object *_jc_gnu_xml_transform_Key$method$clone$3716537eef3cb25b(_jc_env *, struct _jc_gnu_xml_transform_Key$object *, struct _jc_gnu_xml_transform_Stylesheet$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_Key$method_info$clone$3716537eef3cb25b;

// Virtual methods structure
struct _jc_gnu_xml_transform_Key$vmethods {
	struct _jc_gnu_xml_transform_Key$object	*(*clone$3716537eef3cb25b)(_jc_env *, struct _jc_gnu_xml_transform_Key$object *, struct _jc_gnu_xml_transform_Stylesheet$object *);
};

// Vtable
struct _jc_gnu_xml_transform_Key$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_transform_Key$vmethods	gnu_xml_transform_Key;
};

// Vtype
struct _jc_gnu_xml_transform_Key$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_Key$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_Key$sub_refs {
	struct _jc_javax_xml_namespace_QName$object	*name;
	struct _jc_gnu_xml_xpath_Pattern$object	*match;
	struct _jc_gnu_xml_xpath_Expr$object	*use;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_Key$refs {
    _jc_gnu_xml_transform_Key$sub_refs	gnu_xml_transform_Key;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_Key$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_Key$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_transform_Key$sub_nonrefs	gnu_xml_transform_Key;
};

// Object instance structure
struct _jc_gnu_xml_transform_Key$object {
	_jc_gnu_xml_transform_Key$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_Key$vtype	*vtype;
	_jc_gnu_xml_transform_Key$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_Key$vtype _jc_gnu_xml_transform_Key$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_Key, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_Key$class_object;

#endif	/* _JC_gnu_xml_transform_Key_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/transform/Key.h <==
// class gnu.xml.transform.Key

// class file dependencies
// @dep_class a8e21f5a8a9bccaa gnu_xml_transform_Key
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_transform_Key_H_
#define _JC_gnu_xml_transform_Key_H_

// Forward structure declarations
struct _jc_gnu_xml_transform_Key$object;
struct _jc_gnu_xml_transform_Stylesheet$object;
struct _jc_gnu_xml_xpath_Expr$object;
struct _jc_gnu_xml_xpath_Pattern$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_xml_namespace_QName$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_Key$sub_refs	_jc_gnu_xml_transform_Key$sub_refs;
typedef struct _jc_gnu_xml_transform_Key$sub_nonrefs	_jc_gnu_xml_transform_Key$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_Key$refs	_jc_gnu_xml_transform_Key$refs;
typedef struct _jc_gnu_xml_transform_Key$nonrefs	_jc_gnu_xml_transform_Key$nonrefs;
typedef struct _jc_gnu_xml_transform_Key$object	_jc_gnu_xml_transform_Key$object;

typedef const struct _jc_gnu_xml_transform_Key$vmethods	_jc_gnu_xml_transform_Key$vmethods;
typedef const struct _jc_gnu_xml_transform_Key$vtable	_jc_gnu_xml_transform_Key$vtable;
typedef const struct _jc_gnu_xml_transform_Key$vtype	_jc_gnu_xml_transform_Key$vtype;

// Constructors
extern void _jc_gnu_xml_transform_Key$method$_init$08cf062a5167e0de(_jc_env *, struct _jc_gnu_xml_transform_Key$object *, struct _jc_javax_xml_namespace_QName$object *, struct _jc_gnu_xml_xpath_Pattern$object *, struct _jc_gnu_xml_xpath_Expr$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_xml_transform_Key$object *_jc_gnu_xml_transform_Key$method$clone$3716537eef3cb25b(_jc_env *, struct _jc_gnu_xml_transform_Key$object *, struct _jc_gnu_xml_transform_Stylesheet$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_Key$method_info$clone$3716537eef3cb25b;

// Virtual methods structure
struct _jc_gnu_xml_transform_Key$vmethods {
	struct _jc_gnu_xml_transform_Key$object	*(*clone$3716537eef3cb25b)(_jc_env *, struct _jc_gnu_xml_transform_Key$object *, struct _jc_gnu_xml_transform_Stylesheet$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_transform_Key$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_transform_Key$vmethods	gnu_xml_transform_Key;
};

// Vtype
struct _jc_gnu_xml_transform_Key$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_Key$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_Key$sub_refs {
	struct _jc_javax_xml_namespace_QName$object	*name;
	struct _jc_gnu_xml_xpath_Pattern$object	*match;
	struct _jc_gnu_xml_xpath_Expr$object	*use;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_Key$refs {
    _jc_gnu_xml_transform_Key$sub_refs	gnu_xml_transform_Key;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_Key$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_Key$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_transform_Key$sub_nonrefs	gnu_xml_transform_Key;
};

// Object instance structure
struct _jc_gnu_xml_transform_Key$object {
	_jc_gnu_xml_transform_Key$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_Key$vtype	*vtype;
	_jc_gnu_xml_transform_Key$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_Key$vtype _jc_gnu_xml_transform_Key$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_Key, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_Key$class_object;

#endif	/* _JC_gnu_xml_transform_Key_H_ */
